sample_test_with_naarad_run_tests_in_parallel_20150126_223329

### sample_config1

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
3 | 2 | 1 | 0 | 2015-01-26 22:34:03 | 2015-01-26 22:34:09 | 5.67739701271 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test1 | Passed | Test has no docstring :(
test0 | Failed | Yay! Docstring!
test2 | Passed | Another docstring

###

Config Key | Value
--- | ---
TEST_OPTION | foo
BAR | baz